NAME

Module::CheckVersion - Check module (e.g. check latest version) with CPAN (or equivalent repo)

VERSION

This document describes version 0.090 of Module::CheckVersion (from Perl distribution Module-CheckVersion), released on 2026-04-07.

SYNOPSIS

Check latest version of modules:

use Module::CheckVersion qw(check_module_version);

my $res = check_module_version(module => 'Clone');
# sample result: [200, "OK", {latest_version=>'0.38', installed_version=>'0.37', is_latest_version=>0}]

say "Module Clone is the latest version ($res->[2]{latest_version})"
    if $res->[2]{is_latest_version};

FUNCTIONS

check_module_version

Usage:

check_module_version(%args) -> [$status_code, $reason, $payload, \%result_meta]

Check module (e.g. check latest version) with CPAN (or equivalent repo).

Designed to be more general and able to provide more information in the future in addition to mere checking of latest version, but checking latest version is currently the only implemented feature.

Can handle non-CPAN modules, as long as you put the appropriate $AUTHORITY in your modules and create the Module::CheckVersion::<scheme> to handle your authority scheme.

This function is not exported by default, but exportable.

Arguments ('*' denotes required arguments):

  • check_latest_version => bool (default: 1)

    (No description)

  • default_authority_scheme => str (default: "cpan")

    If a module does not set $AUTHORITY (which contains string like <scheme>:<extra> like cpan:PERLANCAR), the default authority scheme will be determined from this setting. The module Module::CheckVersion::<scheme> module is used to implement actual checking.

    Can also be set to undef, in which case when module's $AUTHORITY is not available, will return 412 status.

  • module* => str

    This routine will try to load the module, and retrieve its $VERSION. If loading fails will assume module's installed version is undef.

Returns an enveloped result (an array).

First element ($status_code) is an integer containing HTTP-like status code (200 means OK, 4xx caller error, 5xx function error). Second element ($reason) is a string containing error message, or something like "OK" if status is 200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth element (%result_meta) is called result metadata and is optional, a hash that contains extra information, much like how HTTP response headers provide additional metadata.

Return value: (any)

HOMEPAGE

Please visit the project's homepage at https://metacpan.org/release/Module-CheckVersion.

SOURCE

Source repository is at https://github.com/perlancar/perl-Module-CheckVersion.

SEE ALSO

The distribution comes with a CLI: check-module-version.

AUTHOR

perlancar <perlancar@cpan.org>

CONTRIBUTING

To contribute, you can send patches by email/via RT, or send pull requests on GitHub.

Most of the time, you don't need to build the distribution yourself. You can simply modify the code, then test via:

% prove -l

If you want to build the distribution (e.g. to try to install it locally on your system), you can install Dist::Zilla, Dist::Zilla::PluginBundle::Author::PERLANCAR, Pod::Weaver::PluginBundle::Author::PERLANCAR, and sometimes one or two other Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond that are considered a bug and can be reported to me.

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

BUGS

Please report any bugs or feature requests on the bugtracker website https://rt.cpan.org/Public/Dist/Display.html?Name=Module-CheckVersion

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.